@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(COPYSOURCESHRED__H)
+#if !defined(KPMCORE_COPYSOURCESHRED_H)
 
-#define COPYSOURCESHRED__H
+#define KPMCORE_COPYSOURCESHRED_H
 
 #include "core/copysource.h"
 
@@ -34,14 +34,14 @@ class CopyTarget;
 class CopySourceShred : public CopySource
 {
 public:
-    CopySourceShred(qint64 size, qint32 sectorsize, bool randomShred);
+    CopySourceShred(qint64 size, qint64 sectorsize, bool randomShred);
 
 public:
     bool open() override;
     bool readSectors(void* buffer, qint64 readOffset, qint64 numSectors) override;
     qint64 length() const override;
 
-    qint32 sectorSize() const override {
+    qint64 sectorSize() const override {
         return m_SectorSize;    /**< @return the file's sector size */
     }
     bool overlaps(const CopyTarget&) const override {
@@ -61,13 +61,13 @@ protected:
     const QFile& sourceFile() const {
         return m_SourceFile;
     }
-    qint32 size() const {
+    qint64 size() const {
         return m_Size;
     }
 
 private:
     qint64 m_Size;
-    qint32 m_SectorSize;
+    qint64 m_SectorSize;
     QFile m_SourceFile;
 };
 
