@@ -48,14 +48,15 @@ bool fat32::create(Report& report, const QString& deviceNode)
 
 bool fat32::updateUUID(Report& report, const QString& deviceNode) const
 {
-    qint32 t = time(nullptr);
+    qint64 t = time(nullptr);
 
     char uuid[4];
     for (auto &u : uuid) {
-        u = t & 0xff;
+        u = static_cast<char>(t & 0xff);
         t >>= 8;
     }
 
+    // HACK: replace this hack with fatlabel "-i" (dosfstools 4.2)
     ExternalCommand cmd(report, QStringLiteral("dd"), { QStringLiteral("of=") + deviceNode, QStringLiteral("bs=1"), QStringLiteral("count=4"), QStringLiteral("seek=67") });
 
     if (!cmd.start())
