@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(CREATEFILESYSTEMJOB__H)
+#if !defined(KPMCORE_CREATEFILESYSTEMJOB_H)
 
-#define CREATEFILESYSTEMJOB__H
+#define KPMCORE_CREATEFILESYSTEMJOB_H
 
 #include "jobs/job.h"
 
@@ -33,7 +33,7 @@ class QString;
 class CreateFileSystemJob : public Job
 {
 public:
-    CreateFileSystemJob(Device& d, Partition& p);
+    CreateFileSystemJob(Device& d, Partition& p, const QString& label = {});
 
 public:
     bool run(Report& parent) override;
@@ -57,6 +57,7 @@ protected:
 private:
     Device& m_Device;
     Partition& m_Partition;
+    const QString& m_Label;
 };
 
 #endif
